﻿//-----------------------------------------------------------------------
// <copyright file="Bettor.cs" company="BME MIT">
//     Based on work of Anexa85
//     Original code from: http://www.gamedev.net/topic/536071-c-text-based-blackjack/
//     Modified by David Honfi, BME MIT
// </copyright>
//-----------------------------------------------------------------------
namespace BlackJack
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Threading.Tasks;

    /// <summary>
    /// Implementation of the bettor.
    /// </summary>
    public class Bettor : Player
    {
        /// <summary>
        /// Gets a bet from the bettor and makes sure it is in range.
        /// </summary>
        /// <param name="balance">Current balance</param>
        /// <param name="bet">Value of bet</param>
        public void GetBet(ref int balance, ref int bet)
        {
            bool betValid = false;

            do
            {
                Console.WriteLine("You have {0}.", balance);
                Console.WriteLine("How much would you like to bet?");
                bet = Convert.ToInt32(Console.ReadLine());
                if ((bet <= balance) & (bet > 0))
                {
                    betValid = true;
                }
                else
                {
                    betValid = false;
                }
            }
            while (!betValid);
        }

        /// <summary>
        /// Implements a game turn of the bettor.
        /// </summary>
        /// <param name="deck">The deck of cards.</param>
        /// <param name="dealer">The dealer player.</param>
        /// <param name="bettor">The bettor player</param>
        /// <param name="balance">The bettor's balance</param>
        /// <param name="bet">The bettor's bet</param>
        public void Turn(Deck deck, Dealer dealer, Bettor bettor, ref int balance, ref int bet)
        {
            string playerResponse = "none";
            bool turnOver = false;

            dealer.DealToDealer(deck);
            Console.WriteLine("The dealer shows a:");
            dealer.DisplayHand();

            Console.WriteLine("The dealer shows two cards for you...");

            Console.WriteLine("Your bet was {0}.", bet);
            Console.WriteLine("Your hand is:");

            dealer.DealToBettor(deck, bettor);
            dealer.DealToBettor(deck, bettor);

            this.DisplayHand();
            this.DisplayBettorValue();

            do
            {
                if (this.CalcHandValue() < 21)
                {
                    if ((this.Hand.Cards.Count() < 3) & (playerResponse != "dd"))
                    {
                        Console.WriteLine("Would you like to Hit(h), Stand(s), Double Down(dd) ?");
                    }
                    else
                    {
                        Console.WriteLine("Would you like to Hit(h) or Stand(s) ?");
                    }

                    playerResponse = Console.ReadLine();
                }
                else
                {
                    turnOver = true;
                }

                if (!turnOver)
                {
                    switch (playerResponse)
                    {
                        case "h":
                            if (this.CalcHandValue() < 21)
                            {
                                dealer.DealToBettor(deck, bettor);
                                this.DisplayHand();
                                this.DisplayBettorValue();
                            }
                            else
                            {
                                turnOver = true;
                            }

                            break;
                        case "s":
                            Console.WriteLine("You have chosen to stand.");
                            turnOver = true;
                            this.DisplayBettorValue();
                            Console.WriteLine("Press ENTER to continue!");
                            Console.ReadLine();
                            break;
                        case "dd":
                            if (this.Hand.Cards.Count() < 3)
                            {
                                Console.WriteLine("Your original bet was {0}.", bet);
                                Console.WriteLine("How much additional money would you like to bet? (Only up to original bet.)");
                                bet += Convert.ToInt32(Console.ReadLine());
                                Console.WriteLine("You have now bet {0}.", bet);
                            }
                            else
                            {
                                Console.WriteLine("Doubling down is only available when you have just two cards in your hand.");
                            }

                            break;
                        default:
                            Console.WriteLine("That is not a valid response.");
                            break;
                    }
                }
            }
            while (!turnOver);

            dealer.DisplayDealerValue();
        }

        /// <summary>
        /// Displays the value of the bettor's hand.
        /// </summary>
        public void DisplayBettorValue()
        {
            Console.WriteLine("Your hand value is {0}.", this.CalcHandValue());
        }
    }
}
