﻿//-----------------------------------------------------------------------
// <copyright file="Dealer.cs" company="BME MIT">
//     Based on work of Anexa85
//     Original code from: http://www.gamedev.net/topic/536071-c-text-based-blackjack/
//     Modified by David Honfi, BME MIT
// </copyright>
//-----------------------------------------------------------------------
namespace BlackJack
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Threading.Tasks;

    /// <summary>
    /// Represents the dealer as a player.
    /// </summary>
    public class Dealer : Player
    {
        /// <summary>
        /// Field for the random generator.
        /// </summary>
        private Random randomClass = new Random();
        
        /// <summary>
        /// Creates a deal from the deck to the bettor.
        /// </summary>
        /// <param name="deck">The deck to choose from.</param>
        /// <param name="bettor">The bettor player.</param>
        public void DealToBettor(Deck deck, Bettor bettor)
        {
            bool doneDealing = false;
            do
            {
                int randomNumberOne = this.randomClass.Next(1, 4);
                int randomNumberTwo = this.randomClass.Next(1, 15);

                if (deck.Cards[randomNumberOne, randomNumberTwo].IsFaceUp == false)
                {
                    deck.Cards[randomNumberOne, randomNumberTwo].IsFaceUp = true;
                    bettor.Hand.Cards.Add(deck.Cards[randomNumberOne, randomNumberTwo]);
                    doneDealing = true;
                }
            }
            while (!doneDealing);
        }
        
        /// <summary>
        /// Creates a deal from the deck to the dealer.
        /// </summary>
        /// <param name="deck">The deck to choose from.</param>
        public void DealToDealer(Deck deck)
        {
            bool doneDealing = false;

            do
            {
                int randomNumberOne = this.randomClass.Next(1, 4);
                int randomNumberTwo = this.randomClass.Next(1, 15);

                if (deck.Cards[randomNumberOne, randomNumberTwo].IsFaceUp == false)
                {
                    deck.Cards[randomNumberOne, randomNumberTwo].IsFaceUp = true;
                    Hand.Cards.Add(deck.Cards[randomNumberOne, randomNumberTwo]);
                    doneDealing = true;
                }
            }
            while (!doneDealing);
        }

        /// <summary>
        /// Represents a turn for the dealer.
        /// </summary>
        /// <param name="deck">The deck of cards.</param>
        /// <param name="bettor">The bettor player.</param>
        /// <param name="balance">The bettor's balance.</param>
        /// <param name="bet">The bettor's bet.</param>
        public void Turn(Deck deck, Bettor bettor, ref int balance, ref int bet)
        {
            bool turnOver = false;

            GameLoop.CheckForBust(this, bettor, ref balance, ref bet);

            if (bettor.CalcHandValue() <= 21)
            {
                Console.WriteLine("The dealer is now acting...");

                this.DealToDealer(deck);
                Console.WriteLine("Dealer's hand is now:");
                this.DisplayHand();
                this.DisplayDealerValue();
                Console.WriteLine("Press ENTER to continue!");
                Console.ReadLine();

                do
                {
                    if (this.CalcHandValue() < new Random().Next(16, 19))
                    {
                        Console.WriteLine("The dealer hits.");
                        this.DealToDealer(deck);
                        this.DisplayHand();
                        this.DisplayDealerValue();
                        Console.WriteLine("Press ENTER to continue!");
                        Console.ReadLine();
                        if (this.CalcHandValue() > 21)
                        {
                            turnOver = true;
                        }
                    }
                    else
                    {
                        Console.WriteLine("The dealer stands.");
                        turnOver = true;
                    }
                }
                while (!turnOver);

                if (this.CalcHandValue() <= 21)
                {
                    GameLoop.CheckForWin(this, bettor, ref balance, ref bet);
                }
                else
                {
                    GameLoop.CheckForBust(this, bettor, ref balance, ref bet);
                }
            }
        }

        /// <summary>
        /// Displays the value of the bettor's hand.
        /// </summary>
        public void DisplayDealerValue()
        {
            Console.WriteLine("The dealer's value is {0}.", this.CalcHandValue());
        }
    }
}
