﻿//-----------------------------------------------------------------------
// <copyright file="Deck.cs" company="BME MIT">
//     Based on work of Anexa85
//     Original code from: http://www.gamedev.net/topic/536071-c-text-based-blackjack/
//     Modified by David Honfi, BME MIT
// </copyright>
//-----------------------------------------------------------------------
namespace BlackJack
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Threading.Tasks;

    /// <summary>
    /// Represents the deck of cards.
    /// </summary>
    public class Deck
    {
        /// <summary>
        /// Array of suits.
        /// </summary>
        private SUIT[] suitArray = new SUIT[5];

        /// <summary>
        /// Array of names.
        /// </summary>
        private NAME[] nameArray = new NAME[17];

        /// <summary>
        /// Initializes a new instance of the <see cref="Deck" /> class.
        /// </summary>
        public Deck()
        {
            this.Cards = new Card[5, 15];
        }

        /// <summary>
        /// Gets or sets the array of cards.
        /// </summary>
        public Card[,] Cards { get; set; }

        /// <summary>
        /// Creates a new deck.
        /// </summary>
        public void Create()
        {
            this.suitArray[1] = SUIT.CLUBS;
            this.suitArray[2] = SUIT.SPADES;
            this.suitArray[3] = SUIT.DIAMONDS;
            this.suitArray[4] = SUIT.HEARTS;

            this.nameArray[1] = NAME.ONE;
            this.nameArray[2] = NAME.TWO;
            this.nameArray[3] = NAME.THREE;
            this.nameArray[4] = NAME.FOUR;
            this.nameArray[5] = NAME.FIVE;
            this.nameArray[6] = NAME.SIX;
            this.nameArray[7] = NAME.SEVEN;
            this.nameArray[8] = NAME.EIGHT;
            this.nameArray[9] = NAME.NINE;
            this.nameArray[10] = NAME.TEN;
            this.nameArray[11] = NAME.JACK;
            this.nameArray[12] = NAME.QUEEN;
            this.nameArray[13] = NAME.KING;
            this.nameArray[14] = NAME.ACE;

            for (int i = 1; i <= 4; i++)
            {
                for (int j = 1; j <= 14; j++)
                {
                    this.Cards[i, j] = new Card();
                    this.Cards[i, j].Suit = this.suitArray[i];
                    this.Cards[i, j].Value = j;
                    this.Cards[i, j].Name = this.nameArray[j];
                    if (j > 10)
                    {
                        this.Cards[i, j].Value = 10;
                    }

                    if (j == 14)
                    {
                        this.Cards[i, j].Value = 11;
                    }
                }
            }
        }

        /// <summary>
        /// Displays the deck that was created.
        /// </summary>
        public void DisplayDeck()
        {
            for (int i = 1; i <= 4; i++)
            {
                for (int j = 1; j <= 14; j++)
                {
                    this.Cards[i, j].Display();
                }
            }
        }
    }
}
