﻿//-----------------------------------------------------------------------
// <copyright file="GameLoop.cs" company="BME MIT">
//     Based on work of Anexa85
//     Original code from: http://www.gamedev.net/topic/536071-c-text-based-blackjack/
//     Modified by David Honfi, BME MIT
// </copyright>
//-----------------------------------------------------------------------
namespace BlackJack
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Threading.Tasks;

    /// <summary>
    /// Represents the loop of the BlackJack game.
    /// </summary>
    public static class GameLoop
    {
        /// <summary>
        /// Checks for a bust. It's separated from the CheckForWin so that it can be used midgame to determine if anyone is busted.
        /// </summary>
        /// <param name="dealer">The dealer player.</param>
        /// <param name="bettor">The bettor player.</param>
        /// <param name="gameBalance">The bettor's balance.</param>
        /// <param name="bet">The bettor's bet.</param>
        public static void CheckForBust(Dealer dealer, Bettor bettor, ref int gameBalance, ref int bet)
        {
            int winnings = 0;

            if (dealer.CalcHandValue() > 21)
            {
                Console.WriteLine("Dealer BUSTS.");
                winnings = bet * 2;
                gameBalance += winnings;
                Console.WriteLine("Your new balance is {0}.", gameBalance);
                bet = 0;
            }
            else if (bettor.CalcHandValue() > 21)
            {
                Console.WriteLine("You BUST!");
                gameBalance -= bet;
                Console.WriteLine("Your new balance is {0}.", gameBalance);
                bet = 0;
            }
        }

        /// <summary>
        /// Checks for a winner and if there is one, then it puts the message and modifies the balance.
        /// </summary>
        /// <param name="dealer">The dealer player.</param>
        /// <param name="bettor">The bettor player.</param>
        /// <param name="balance">The bettor's balance.</param>
        /// <param name="bet">The bettor's bet.</param>
        public static void CheckForWin(Dealer dealer, Bettor bettor, ref int balance, ref int bet)
        {
            int winnings = 0;

            if ((bettor.Hand.Cards.Count() < 3) & (bettor.CalcHandValue() == 21) & (dealer.Hand.Cards.Count() < 3) & (dealer.CalcHandValue() == 21))
            {
                Console.WriteLine("Dealer and Bettor get BLACKJACK... It's a tie!");

                Console.WriteLine("Your new balance is {0}.", balance);
            }
            else if ((bettor.Hand.Cards.Count() < 3) & (bettor.CalcHandValue() == 21))
            {
                Console.WriteLine("Bettor has a BLACKJACK!");
                Console.WriteLine("You WON!");
                winnings = bet * 3;
                balance += winnings;
                Console.WriteLine("Your new balance is {0}.", balance);
            }
            else if ((dealer.Hand.Cards.Count() < 3) & (dealer.CalcHandValue() == 21))
            {
                Console.WriteLine("Dealer has a BLACKJACK!");
                Console.WriteLine("Dealer WINS!");
                balance -= bet;
                Console.WriteLine("Your new balance is {0}.", balance);
            }
            else if (bettor.CalcHandValue() == dealer.CalcHandValue())
            {
                Console.WriteLine("It's a tie!");
                Console.WriteLine("Your new balance is {0}.", balance);
            }
            else if (dealer.CalcHandValue() > bettor.CalcHandValue())
            {
                balance -= bet;
                Console.WriteLine("Dealer WINS!");
                Console.WriteLine("Your new balance is {0}.", balance);
            }
            else if (dealer.CalcHandValue() < bettor.CalcHandValue())
            {
                winnings = bet * 2;
                balance += winnings;
                Console.WriteLine("The bet was {0}.", bet);
                Console.WriteLine("You WON!");
                Console.WriteLine("Your new balance is {0}.", balance);
            }
        }

        /// <summary>
        /// Runs the loop.
        /// </summary>
        public static void Run()
        {
            string playerAnswer = "none";
            int gameBalance = 250;

            Bettor bettor = new Bettor();
            Dealer dealer = new Dealer();

            Console.WriteLine("Welcome to IRF-2013 BlackJack!");
            do
            {
                Console.WriteLine("Starting new round...");

                int bet = 0;

                Deck deck = new Deck();

                deck.Create();

                bettor.Hand = new Hand();
                dealer.Hand = new Hand();

                bettor.GetBet(ref gameBalance, ref bet);

                bettor.Turn(deck, dealer, bettor, ref gameBalance, ref bet);
                dealer.Turn(deck, bettor, ref gameBalance, ref bet);

                Console.WriteLine("Would you like to play again(y), or no(n)?");
                playerAnswer = Console.ReadLine();

                if (gameBalance <= 0)
                {
                    Console.WriteLine("You lost all of your money!");

                    if (playerAnswer == "y")
                    {
                        Console.WriteLine("Time for a refill!");
                        gameBalance = 250;
                        Console.ReadLine();
                    }
                }
            }
            while (playerAnswer != "n");
        }
    }
}
